/******************************************************************************

   Copyright 1991 Lee Iverson

   Permission to use, copy, modify, and distribute this software and its
   documentation for any purpose without fee is hereby granted without fee,
   provided that the above copyright notice appear in all copies and that
   both that copyright notice and this permission notice appear in
   supporting documentation, and that the name of McGill not be used in
   advertising or publicity pertaining to distribution of the software
   without specific, written prior permission.  McGill makes no
   representations about the suitability of this software for any purpose.
   It is provided "as is" without express or implied warranty.

   MCGILL DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING ALL
   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL MCGILL
   BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
   WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION
   OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
   CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.

   Author:
     Lee Iverson <leei@mcrcim.mcgill.edu>,
     McGill Research Centre for Intelligent Machines (McRCIM)

******************************************************************************/

static char RCSid[] = "$Id: stderr_notif.c,v 0.9.1.1 1991/11/06 00:09:25 leei Exp $";

#include <stdio.h>
#include <stdlib.h>
#include <notifier.h>

#include <sys/types.h>
#include <unistd.h>

#include "proto.h"

pid_t
stderrNotifier _IMPL((name), char *name )
{
    pid_t pid;
    int to_notifier[2];

    if ( pipe(to_notifier) ) {
	fprintf( stderr, "Failed to create pipe for notifier.\n" );
	return 0;
    }

    if ( !(pid = vfork()) ) {
	/* Exec notifier process and ... */
	dup2( to_notifier[0], 0 ); /* Pipe -> stdin of notifier. */
	close(to_notifier[0]); close(to_notifier[1]);
	execlp( "notifier", name, 0 );
	exit(1);
    } else {
	if ( waitpid( pid, WNOHANG ) != pid ) {
	    /* Attach input end of pipe to stderr. */
	    dup2( to_notifier[1], 2 ); /* Pipe <- stderr of process. */
	    close(to_notifier[0]); close(to_notifier[1]);
	}
    }

    return pid;
}
